@@ -1,7 +1,7 @@
 package CPANPLUS::Internals::Fetch;
 
 use strict;
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 
@@ -294,7 +294,7 @@ sub __file_fetch {
     my $ff = File::Fetch->new( uri => $where );
 
     ### sanity check ###
-    error(loc("Bad uri '%1'",$where)),next unless $ff;
+    error(loc("Bad uri '%1'",$where)), return unless $ff;
 
     if( my $file = $ff->fetch( to => $local_path ) ) {
         unless( -e $file && -s _ ) {
