@@ -1,7 +1,7 @@
 package CPANPLUS::Internals::Source;
 
 use strict;
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Module;
 use CPANPLUS::Module::Fake;
@@ -52,7 +52,7 @@ The flow looks like this:
                 $cb->__retrieve_source
                 $cb->__create_dslip_tree
                     $cb->__retrieve_source
-    $cb->_save_source
+            $cb->_save_source
 
     $cb->_dslip_defs
 
@@ -359,7 +359,6 @@ Returns a boolean indicating success.
 =cut
 
 ### (re)build the trees ###
-### takes one optional argument, which indicates if we're already up-to-date. ###
 sub _build_trees {
     my ($self, %hash)   = @_;
     my $conf            = $self->configure_object;
@@ -398,8 +397,11 @@ sub _build_trees {
     ### return if we weren't able to build the trees ###
     return unless $self->{_modtree} && $self->{_authortree};
 
-    ### only do it at the end of the program, not after parsing ###
-    #$self->_save_source( map { $_ => $args->{$_} } qw[path verbose] );
+    ### write the stored files to disk, so we can keep using them
+    ### from now on, till they become invalid
+    ### write them if the original sources weren't uptodate, or
+    ### we didn't just load storable files
+    $self->_save_source() if !$uptodate or not keys %$stored;
 
     ### still necessary? can only run one instance now ###
     ### will probably stay that way --kane
@@ -466,16 +468,7 @@ sub __retrieve_source {
     return unless $storable;
 
     ### $stored is the name of the frozen data structure ###
-    my $stored = File::Spec->rel2abs(
-                    File::Spec->catfile(
-                                $args->{path},      #base dir
-                                #$args->{name}       #file
-                                $conf->_get_source('stored')
-                                . '.' .
-                                $Storable::VERSION  #the version of storable used to store
-                                . '.stored'         #append a suffix
-                    )
-                );
+    my $stored = $self->__storable_file( $args->{path} );
 
     if ($storable && -e $stored && -s _ && $args->{'uptodate'}) {
         msg( loc("Retrieving %1", $stored), $args->{'verbose'} );
@@ -545,21 +538,14 @@ sub _save_source {
     return unless keys %$to_write;
 
     ### $stored is the name of the frozen data structure ###
-    ### changed to use File::Spec->catfile -jmb
-    my $stored = File::Spec->catfile(
-                            $args->{path},                  #base dir
-                            $conf->_get_source('stored')    #file
-                            . '.' .
-                            $Storable::VERSION              #the version of storable used to store
-                            . '.stored'                     #append a suffix
-                        );
+    my $stored = $self->__storable_file( $args->{path} );
 
     if (-e $stored && not -w $stored) {
         msg( loc("%1 not writable; skipped.", $stored), $args->{'verbose'} );
         return;
     }
 
-    msg( loc("Writing state information back to disk. This may take a little while."),
+    msg( loc("Writing compiled source information to disk. This might take a little while."),
 	    $args->{'verbose'} );
 
     my $flag;
@@ -571,6 +557,32 @@ sub _save_source {
     return $flag ? 0 : 1;
 }
 
+sub __storable_file {
+    my $self = shift;
+    my $conf = $self->configure_object;
+    my $path = shift or return;
+
+    ### check if we can retrieve a frozen data structure with storable ###
+    my $storable = $conf->get_conf('storable')
+                        ? can_load( modules => {'Storable' => '0.0'} )
+                        : 0;
+
+    return unless $storable;
+    
+    ### $stored is the name of the frozen data structure ###
+    ### changed to use File::Spec->catfile -jmb
+    my $stored = File::Spec->rel2abs(
+        File::Spec->catfile(
+            $path,                          #base dir
+            $conf->_get_source('stored')    #file
+            . '.' .
+            $Storable::VERSION              #the version of storable 
+            . '.stored'                     #append a suffix
+        )
+    );
+
+    return $stored;
+}
 
 =pod
 
