@@ -8,7 +8,7 @@ package CPANPLUS::Shell::Classic;
 
 use strict;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Backend;
 use CPANPLUS::Configure::Setup;
@@ -30,7 +30,7 @@ $Params::Check::ALLOW_UNKNOWN = 1;
 BEGIN {
     use vars        qw[ $VERSION @ISA ];
     @ISA        =   qw[ CPANPLUS::Shell::_Base::ReadLine ];
-    $VERSION    =   '0.056_01';
+    $VERSION    =   '0.0562';
 }
 
 load CPANPLUS::Shell;
@@ -124,7 +124,7 @@ sub _input_loop {
             $SIG{$sig} = $entry->{handler} if exists($entry->{handler});
         }
 
-        last if $self->dispatch_on_input( input => $input );
+        last if $self->_dispatch_on_input( input => $input );
 
         ### flush the lib cache ###
         $cb->_flush( list => [qw|lib load|] );
